instrumenttools.Glockenspiel
============================

.. abjad-lineage:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel

.. autoclass:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Glockenspiel.Glockenspiel.Glockenspiel.__repr__
   :noindex:
